Structs
- Bridge
View - Read-only view over the seeded query state of a
SharedBridge. - Script
Engine - Shared
Bridge - Shared state between the JS runtime and the Rust game loop.
Commands issued by JS
await game.showText(...)are placed here; the game loop reads them, executes the operation, then callssignal_done.